[![Build status](https://travis-ci.org/lowandrew/ConFindr.svg?master)](https://travis-ci.org/lowandrew)
[![PyPI version](https://badge.fury.io/py/confindr.svg)](https://badge.fury.io/py/confindr)
[![install with bioconda](https://img.shields.io/badge/install%20with-bioconda-brightgreen.svg?style=flat-square)](http://bioconda.github.io/recipes/confindr/README.html)

# ConFindr

This program is designed to find bacterial intra-species contamination in raw NGS data. It does this
 by looking for multiple copies of rMLST genes, which are known to be universal across the bacterial kingdom
 and present only in single copies. It has been tested and found to be highly sensitive and specific.

For instructions on installation and usage, please visit [the ConFindr github pages site](https://lowandrew.github.io/ConFindr/).
